@@ -10,6 +10,7 @@
 extern "C" {
 #include <afs/param.h>
 #include <afs/stds.h>
+#include <afs/fs_utils.h>
 }
 
 #include "afscreds.h"
@@ -220,12 +221,17 @@ void WizStarting_OnInitDialog (HWND hDlg)
    ShowWindow (GetDlgItem (hDlg, IDC_START_TRY), SW_SHOW);
 
    SC_HANDLE hManager;
-   if ((hManager = OpenSCManager (NULL, NULL, SC_MANAGER_ALL_ACCESS)) != NULL)
+    if ((hManager = OpenSCManager (NULL, NULL, 
+                                   SC_MANAGER_CONNECT |
+                                   SC_MANAGER_ENUMERATE_SERVICE |
+                                   SC_MANAGER_QUERY_LOCK_STATUS)) != NULL)
       {
       SC_HANDLE hService;
-      if ((hService = OpenService (hManager, TEXT("TransarcAFSDaemon"), SERVICE_ALL_ACCESS)) != NULL)
+          if ((hService = OpenService (hManager, TEXT("TransarcAFSDaemon"), 
+                                       SERVICE_QUERY_STATUS | SERVICE_START)) != NULL)
          {
-         StartService (hService, 0, 0);
+         if (StartService (hService, 0, 0))
+			TestAndDoMapShare(SERVICE_START_PENDING);
 
          CloseServiceHandle (hService);
          }
@@ -253,6 +259,7 @@ void WizStarting_OnTimer (HWND hDlg)
          {
          QueryServiceStatus (hService, &Status);
          CloseServiceHandle (hService);
+		 TestAndDoMapShare(Status.dwCurrentState);
          }
 
       CloseServiceHandle (hManager);
@@ -493,7 +500,7 @@ void WizMount_OnInitDialog (HWND hDlg)
    SendMessage (hCombo, WM_SETREDRAW, TRUE, 0);
    SendMessage (hCombo, CB_SETCURSEL, iItemSel, 0);
 
-   SetDlgItemText (hDlg, IDC_MAP_PATH, TEXT("/afs"));
+   SetDlgItemText (hDlg, IDC_MAP_PATH, cm_slash_mount_root);
 
    CheckDlgButton (hDlg, IDC_NOMAP, FALSE);
    CheckDlgButton (hDlg, IDC_YESMAP, TRUE);
