@@ -19,13 +19,14 @@
  */
 
 #include <afsconfig.h>
-#include "../afs/param.h"
+#include "afs/param.h"
 
-RCSID("$Header: /cvs/openafs/src/afs/FBSD/osi_vm.c,v 1.4 2002/02/16 18:23:49 shadow Exp $");
+RCSID
+    ("$Header: /cvs/openafs/src/afs/FBSD/osi_vm.c,v 1.10 2003/07/15 23:14:20 shadow Exp $");
 
-#include "../afs/sysincludes.h"	/* Standard vendor system headers */
-#include "../afs/afsincludes.h"	/* Afs-based standard headers */
-#include "../afs/afs_stats.h"  /* statistics */
+#include "afs/sysincludes.h"	/* Standard vendor system headers */
+#include "afsincludes.h"	/* Afs-based standard headers */
+#include "afs/afs_stats.h"	/* statistics */
 #include <vm/vm_object.h>
 #include <vm/vm_map.h>
 #include <limits.h>
@@ -48,9 +49,7 @@ RCSID("$Header: /cvs/openafs/src/afs/FBSD/osi_vm.c,v 1.4 2002/02/16 18:23:49 sha
  * OSF/1 Locking:  VN_LOCK has been called.
  */
 int
-osi_VM_FlushVCache(avc, slept)
-    struct vcache *avc;
-    int *slept;
+osi_VM_FlushVCache(struct vcache *avc, int *slept)
 {
     struct vm_object *obj;
     struct vnode *vp;
@@ -65,19 +64,19 @@ osi_VM_FlushVCache(avc, slept)
 	return EBUSY;
 
     AFS_GUNLOCK();
-    vp=avc;
+    vp = AFSTOV(avc);
     simple_lock(&vp->v_interlock);
     if (VOP_GETVOBJECT(vp, &obj) == 0) {
-       vm_object_page_remove(obj, 0, 0, FALSE);
+	vm_object_page_remove(obj, 0, 0, FALSE);
 #if 0
-        if (obj->ref_count == 0) {
-           vgonel(vp,curproc);
-           simple_lock(&vp->v_interlock);
-           vp->v_tag=VT_AFS;
-           SetAfsVnode(vp);
-        }
+	if (obj->ref_count == 0) {
+	    vgonel(vp, curproc);
+	    simple_lock(&vp->v_interlock);
+	    vp->v_tag = VT_AFS;
+	    SetAfsVnode(vp);
+	}
 #endif
-    } 
+    }
     simple_unlock(&vp->v_interlock);
     AFS_GLOCK();
 
@@ -90,35 +89,38 @@ osi_VM_FlushVCache(avc, slept)
  * re-obtained.
  */
 void
-osi_VM_StoreAllSegments(avc)
-    struct vcache *avc;
+osi_VM_StoreAllSegments(struct vcache *avc)
 {
     struct vnode *vp;
     struct vm_object *obj;
-    int anyio,tries;
+    int anyio, tries;
+
     ReleaseWriteLock(&avc->lock);
     AFS_GUNLOCK();
-    tries=5;
-    vp=avc;
+    tries = 5;
+    vp = AFSTOV(avc);
     do {
-    anyio=0;
-    simple_lock(&vp->v_interlock);
-    if (VOP_GETVOBJECT(vp, &obj) == 0 &&
-       (obj->flags & OBJ_MIGHTBEDIRTY)) {
-        if (!vget(vp,
-            LK_INTERLOCK | LK_EXCLUSIVE | LK_RETRY | LK_NOOBJ, curproc)) {
-            if (VOP_GETVOBJECT(vp, &obj) == 0) {
-               vm_object_page_clean(obj, 0, 0, OBJPC_SYNC);
-               anyio = 1;
-            }
-            vput(vp);
-        }
-    } else {
-        simple_unlock(&vp->v_interlock);
-    }
+	anyio = 0;
+	simple_lock(&vp->v_interlock);
+	if (VOP_GETVOBJECT(vp, &obj) == 0 && (obj->flags & OBJ_MIGHTBEDIRTY)) {
+#ifdef AFS_FBSD50_ENV
+	    if (!vget(vp, LK_INTERLOCK | LK_EXCLUSIVE | LK_RETRY, curthread)) {
+#else
+	    if (!vget
+		(vp, LK_INTERLOCK | LK_EXCLUSIVE | LK_RETRY | LK_NOOBJ,
+		 curproc)) {
+#endif
+		if (VOP_GETVOBJECT(vp, &obj) == 0) {
+		    vm_object_page_clean(obj, 0, 0, OBJPC_SYNC);
+		    anyio = 1;
+		}
+		vput(vp);
+	    }
+	} else
+	    simple_unlock(&vp->v_interlock);
     } while (anyio && (--tries > 0));
     AFS_GLOCK();
-    ObtainWriteLock(&avc->lock,94);
+    ObtainWriteLock(&avc->lock, 94);
 }
 
 /* Try to invalidate pages, for "fs flush" or "fs flushv"; or
@@ -131,43 +133,44 @@ osi_VM_StoreAllSegments(avc)
  * be some pages around when we return, newly created by concurrent activity.
  */
 void
-osi_VM_TryToSmush(avc, acred, sync)
-    struct vcache *avc;
-    struct AFS_UCRED *acred;
-    int sync;
+osi_VM_TryToSmush(struct vcache *avc, struct AFS_UCRED *acred, int sync)
 {
     struct vnode *vp;
     struct vm_object *obj;
     int anyio, tries;
+
     ReleaseWriteLock(&avc->lock);
     AFS_GUNLOCK();
-    tries=5;
-    vp=avc;
+    tries = 5;
+    vp = AFSTOV(avc);
     do {
-       anyio=0;
-       simple_lock(&vp->v_interlock);
-       if (VOP_GETVOBJECT(vp, &obj) == 0 &&
-          (obj->flags & OBJ_MIGHTBEDIRTY)) {
-           if (!vget(vp,
-               LK_INTERLOCK | LK_EXCLUSIVE | LK_RETRY | LK_NOOBJ, curproc)) {
-               if (VOP_GETVOBJECT(vp, &obj) == 0) {
-                  vm_object_page_clean(obj, 0, 0, OBJPC_SYNC);
-                  anyio = 1;
-               }
-               vput(vp);
-           }
-       } else {
-           simple_unlock(&vp->v_interlock);
-       }
+	anyio = 0;
+	simple_lock(&vp->v_interlock);
+	if (VOP_GETVOBJECT(vp, &obj) == 0 && (obj->flags & OBJ_MIGHTBEDIRTY)) {
+#ifdef AFS_FBSD50_ENV
+	    if (!vget(vp, LK_INTERLOCK | LK_EXCLUSIVE | LK_RETRY, curthread)) {
+#else
+	    if (!vget
+		(vp, LK_INTERLOCK | LK_EXCLUSIVE | LK_RETRY | LK_NOOBJ,
+		 curproc)) {
+#endif
+		if (VOP_GETVOBJECT(vp, &obj) == 0) {
+		    vm_object_page_clean(obj, 0, 0, OBJPC_SYNC);
+		    anyio = 1;
+		}
+		vput(vp);
+	    }
+	} else
+	    simple_unlock(&vp->v_interlock);
     } while (anyio && (--tries > 0));
     simple_lock(&vp->v_interlock);
     if (VOP_GETVOBJECT(vp, &obj) == 0) {
-       vm_object_page_remove(obj, 0, 0, FALSE);
+	vm_object_page_remove(obj, 0, 0, FALSE);
     }
     simple_unlock(&vp->v_interlock);
-    /*vinvalbuf(((struct vnode *)avc),0, NOCRED, curproc, 0,0);*/
+    /*vinvalbuf(AFSTOV(avc),0, NOCRED, curproc, 0,0); */
     AFS_GLOCK();
-    ObtainWriteLock(&avc->lock,59);
+    ObtainWriteLock(&avc->lock, 59);
 }
 
 /* Purge VM for a file when its callback is revoked.
@@ -175,21 +178,18 @@ osi_VM_TryToSmush(avc, acred, sync)
  * Locking:  No lock is held, not even the global lock.
  */
 void
-osi_VM_FlushPages(avc, credp)
-    struct vcache *avc;
-    struct AFS_UCRED *credp;
+osi_VM_FlushPages(struct vcache *avc, struct AFS_UCRED *credp)
 {
     struct vnode *vp;
     struct vm_object *obj;
-    printf("|");
-    vp=avc;
+
+    vp = AFSTOV(avc);
     simple_lock(&vp->v_interlock);
     if (VOP_GETVOBJECT(vp, &obj) == 0) {
-       printf("X|");
-       vm_object_page_remove(obj, 0, 0, FALSE);
+	vm_object_page_remove(obj, 0, 0, FALSE);
     }
     simple_unlock(&vp->v_interlock);
-    /*vinvalbuf(((struct vnode *)avc),0, NOCRED, curproc, 0,0);*/
+    /*vinvalbuf(AFSTOV(avc),0, NOCRED, curproc, 0,0); */
 }
 
 /* Purge pages beyond end-of-file, when truncating a file.
@@ -199,10 +199,7 @@ osi_VM_FlushPages(avc, credp)
  * it only works on Solaris.
  */
 void
-osi_VM_Truncate(avc, alen, acred)
-    struct vcache *avc;
-    int alen;
-    struct AFS_UCRED *acred;
+osi_VM_Truncate(struct vcache *avc, int alen, struct AFS_UCRED *acred)
 {
-    vnode_pager_setsize(((struct vnode *)avc), alen);
+    vnode_pager_setsize(AFSTOV(avc), alen);
 }
