@@ -10,7 +10,8 @@
 #include <afsconfig.h>
 #include <afs/param.h>
 
-RCSID("$Header: /cvs/openafs/src/budb/struct_ops.c,v 1.4 2001/07/12 19:58:28 shadow Exp $");
+RCSID
+    ("$Header: /cvs/openafs/src/budb/struct_ops.c,v 1.6 2003/07/15 23:14:48 shadow Exp $");
 
 #include <stdio.h>
 #ifdef AFS_NT40_ENV
@@ -39,8 +40,8 @@ printDbHeader(ptr)
      struct DbHeader *ptr;
 {
     printf("version = %d\n", ptr->dbversion);
-    printf("created = %s", ctime((time_t *)&ptr->created));
-    printf("cell = %s\n",ptr->cell);
+    printf("created = %s", ctime((time_t *) & ptr->created));
+    printf("cell = %s\n", ptr->cell);
     printf("lastDumpId = %u\n", ptr->lastDumpId);
     printf("lastInstanceId = %d\n", ptr->lastInstanceId);
     printf("lastTapeId = %d\n", ptr->lastTapeId);
@@ -50,18 +51,18 @@ printDump(fid, dptr)
      FILE *fid;
      struct dump *dptr;
 {
-    fprintf(fid,"id = %u\n", dptr->id);
-    fprintf(fid,"idHashChain = %d\n", dptr->idHashChain);
-    fprintf(fid,"name = %s\n", dptr->dumpName);
-    fprintf(fid,"vsname = %s\n", dptr->volumeSet);
-    fprintf(fid,"dumpPath = %s\n", dptr->dumpPath);
-    fprintf(fid,"nameHashChain = %d\n", dptr->nameHashChain);
-    fprintf(fid,"flags = 0x%x\n", dptr->flags);
-    fprintf(fid,"parent = %u\n", dptr->parent);
-    fprintf(fid,"created = %s", ctime((time_t *)&dptr->created));
-    fprintf(fid,"nVolumes = %d\n", dptr->nVolumes);
+    fprintf(fid, "id = %u\n", dptr->id);
+    fprintf(fid, "idHashChain = %d\n", dptr->idHashChain);
+    fprintf(fid, "name = %s\n", dptr->dumpName);
+    fprintf(fid, "vsname = %s\n", dptr->volumeSet);
+    fprintf(fid, "dumpPath = %s\n", dptr->dumpPath);
+    fprintf(fid, "nameHashChain = %d\n", dptr->nameHashChain);
+    fprintf(fid, "flags = 0x%x\n", dptr->flags);
+    fprintf(fid, "parent = %u\n", dptr->parent);
+    fprintf(fid, "created = %s", ctime((time_t *) & dptr->created));
+    fprintf(fid, "nVolumes = %d\n", dptr->nVolumes);
     /* printTapeSet(&dptr->tapes); */
-    fprintf(fid,"firstTape = %d\n", dptr->firstTape);
+    fprintf(fid, "firstTape = %d\n", dptr->firstTape);
     /* printKtcPrincipal(&dptr->dumper); */
 
 }
@@ -75,18 +76,25 @@ printDumpEntry(deptr)
     printf("parent = %u\n", deptr->parent);
     printf("level = %d\n", deptr->level);
     printf("flags = 0x%x", deptr->flags);
-       if (deptr->flags == 0)                   printf(": Successful");
-       if (deptr->flags & BUDB_DUMP_INCOMPLETE) printf(": Incomplete");
-       if (deptr->flags & BUDB_DUMP_TAPEERROR)  printf(": Tape error");
-       if (deptr->flags & BUDB_DUMP_INPROGRESS) printf(": In progress");
-       if (deptr->flags & BUDB_DUMP_ABORTED)    printf(": Aborted");
-       if (deptr->flags & BUDB_DUMP_ADSM)       printf(": (ADSM)");       /* XBSA interface to ADSM */
-       if (deptr->flags & BUDB_DUMP_BUTA)       printf(": (BUTA)");       /* buta dump */
-       printf("\n");
+    if (deptr->flags == 0)
+	printf(": Successful");
+    if (deptr->flags & BUDB_DUMP_INCOMPLETE)
+	printf(": Incomplete");
+    if (deptr->flags & BUDB_DUMP_TAPEERROR)
+	printf(": Tape error");
+    if (deptr->flags & BUDB_DUMP_INPROGRESS)
+	printf(": In progress");
+    if (deptr->flags & BUDB_DUMP_ABORTED)
+	printf(": Aborted");
+    if (deptr->flags & BUDB_DUMP_ADSM)
+	printf(": (ADSM)");	/* XBSA interface to ADSM */
+    if (deptr->flags & BUDB_DUMP_BUTA)
+	printf(": (BUTA)");	/* buta dump */
+    printf("\n");
     printf("volumeSet = %s\n", deptr->volumeSetName);
     printf("dump path = %s\n", deptr->dumpPath);
     printf("name = %s\n", deptr->name);
-    printf("created = %s", ctime((time_t *)&deptr->created));
+    printf("created = %s", ctime((time_t *) & deptr->created));
     printf("nVolumes = %d\n", deptr->nVolumes);
 
     printTapeSet(&deptr->tapes, (deptr->flags & BUDB_DUMP_XBSA_NSS));
@@ -101,14 +109,14 @@ printHashTable(fid, htptr)
      FILE *fid;
      struct hashTable *htptr;
 {
-    fprintf(fid,"functionType = %d\n", htptr->functionType);
-    fprintf(fid,"threadOffset = %d\n", htptr->threadOffset);
-    fprintf(fid,"entries = %d\n", htptr->entries);
-    fprintf(fid,"length = %d\n", htptr->length);
-    fprintf(fid,"table = %d\n", htptr->table);
-    fprintf(fid,"progress = %d\n", htptr->progress);
-    fprintf(fid,"oldLength = %d\n", htptr->oldLength);
-    fprintf(fid,"oldTable = %d\n", htptr->oldTable);
+    fprintf(fid, "functionType = %d\n", htptr->functionType);
+    fprintf(fid, "threadOffset = %d\n", htptr->threadOffset);
+    fprintf(fid, "entries = %d\n", htptr->entries);
+    fprintf(fid, "length = %d\n", htptr->length);
+    fprintf(fid, "table = %d\n", htptr->table);
+    fprintf(fid, "progress = %d\n", htptr->progress);
+    fprintf(fid, "oldLength = %d\n", htptr->oldLength);
+    fprintf(fid, "oldTable = %d\n", htptr->oldTable);
 }
 
 /* printMemoryHashTable
@@ -118,11 +126,11 @@ printMemoryHashTable(fid, mhtptr)
      FILE *fid;
      struct memoryHashTable *mhtptr;
 {
-    fprintf(fid,"threadOffset = %d\n", mhtptr->threadOffset);
-    fprintf(fid,"length = %d\n", mhtptr->length);
-    fprintf(fid,"progress = %d\n", mhtptr->progress);
-    fprintf(fid,"size = %d\n", mhtptr->size);
-    fprintf(fid,"oldsize = %d\n", mhtptr->oldSize);
+    fprintf(fid, "threadOffset = %d\n", mhtptr->threadOffset);
+    fprintf(fid, "length = %d\n", mhtptr->length);
+    fprintf(fid, "progress = %d\n", mhtptr->progress);
+    fprintf(fid, "size = %d\n", mhtptr->size);
+    fprintf(fid, "oldsize = %d\n", mhtptr->oldSize);
 }
 
 printPrincipal(ptr)
@@ -145,20 +153,20 @@ printTape(fid, tptr)
      FILE *fid;
      struct tape *tptr;
 {
-    fprintf(fid,"name = %s\n", tptr->name);
-    fprintf(fid,"nameHashChain = %d\n", tptr->nameHashChain);
-    fprintf(fid,"flags = 0x%x\n", tptr->flags);
-    fprintf(fid,"written = %s", ctime((time_t *)&tptr->written));
-    fprintf(fid,"nMBytes = %d\n", tptr->nMBytes);
-    fprintf(fid,"nBytes = %d\n", tptr->nBytes);
-    fprintf(fid,"nFiles = %d\n", tptr->nFiles);
-    fprintf(fid,"nVolumes = %d\n", tptr->nVolumes);
-    fprintf(fid,"seq = %d\n", tptr->seq);
-    fprintf(fid,"dump = %d\n", tptr->dump);
-    fprintf(fid,"nextTape = %d\n", tptr->nextTape);
-    fprintf(fid,"firstVol = %d\n", tptr->firstVol);
-    fprintf(fid,"labelPos = %d\n", tptr->labelpos);
-    fprintf(fid,"useCount = %d\n", tptr->useCount);
+    fprintf(fid, "name = %s\n", tptr->name);
+    fprintf(fid, "nameHashChain = %d\n", tptr->nameHashChain);
+    fprintf(fid, "flags = 0x%x\n", tptr->flags);
+    fprintf(fid, "written = %s", ctime((time_t *) & tptr->written));
+    fprintf(fid, "nMBytes = %d\n", tptr->nMBytes);
+    fprintf(fid, "nBytes = %d\n", tptr->nBytes);
+    fprintf(fid, "nFiles = %d\n", tptr->nFiles);
+    fprintf(fid, "nVolumes = %d\n", tptr->nVolumes);
+    fprintf(fid, "seq = %d\n", tptr->seq);
+    fprintf(fid, "dump = %d\n", tptr->dump);
+    fprintf(fid, "nextTape = %d\n", tptr->nextTape);
+    fprintf(fid, "firstVol = %d\n", tptr->firstVol);
+    fprintf(fid, "labelPos = %d\n", tptr->labelpos);
+    fprintf(fid, "useCount = %d\n", tptr->useCount);
 }
 
 printTapeEntry(teptr)
@@ -166,15 +174,21 @@ printTapeEntry(teptr)
 {
     printf("name = %s\n", teptr->name);
     printf("flags = 0x%x", teptr->flags);
-       if (teptr->flags & BUDB_TAPE_TAPEERROR)    printf(": Error");
-       if (teptr->flags & BUDB_TAPE_DELETED)      printf(": Deleted");
-       if (teptr->flags & BUDB_TAPE_BEINGWRITTEN) printf(": In progress");
-       if (teptr->flags & BUDB_TAPE_ABORTED)      printf(": Aborted");
-       if (teptr->flags & BUDB_TAPE_STAGED)       printf(": Staged");
-       if (teptr->flags & BUDB_TAPE_WRITTEN)      printf(": Successful");
-       printf("\n");
-    printf("written = %s", ctime((time_t *)&teptr->written));
-    printf("expires = %s", cTIME((time_t *)&teptr->expires));
+    if (teptr->flags & BUDB_TAPE_TAPEERROR)
+	printf(": Error");
+    if (teptr->flags & BUDB_TAPE_DELETED)
+	printf(": Deleted");
+    if (teptr->flags & BUDB_TAPE_BEINGWRITTEN)
+	printf(": In progress");
+    if (teptr->flags & BUDB_TAPE_ABORTED)
+	printf(": Aborted");
+    if (teptr->flags & BUDB_TAPE_STAGED)
+	printf(": Staged");
+    if (teptr->flags & BUDB_TAPE_WRITTEN)
+	printf(": Successful");
+    printf("\n");
+    printf("written = %s", ctime((time_t *) & teptr->written));
+    printf("expires = %s", cTIME((time_t *) & teptr->expires));
     printf("kBytes Tape Used = %u\n", teptr->useKBytes);
     printf("nMBytes Data = %d\n", teptr->nMBytes);
     printf("nBytes  Data = %d\n", teptr->nBytes);
@@ -188,16 +202,16 @@ printTapeEntry(teptr)
 
 printTapeSet(tsptr, nss)
      struct budb_tapeSet *tsptr;
-     afs_int32 nss;                 /* is the tapeserver name an accurate name */
+     afs_int32 nss;		/* is the tapeserver name an accurate name */
 {
-    printf("Group id  = %d\n",tsptr->id );
-    printf("tapeServer = %s%s\n",
-	   tsptr->tapeServer, (nss?" (single server)":""));
-    printf("format = %s\n",tsptr->format);
-    printf("maxTapes = %d\n",tsptr->maxTapes);
+    printf("Group id  = %d\n", tsptr->id);
+    printf("tapeServer = %s%s\n", tsptr->tapeServer,
+	   (nss ? " (single server)" : ""));
+    printf("format = %s\n", tsptr->format);
+    printf("maxTapes = %d\n", tsptr->maxTapes);
 /*  printf("a  = %d\n",tsptr->a ); */
 /*  printf("b = %d\n",tsptr->b);   */
-    printf("Start Tape Seq = %d\n",tsptr->b);
+    printf("Start Tape Seq = %d\n", tsptr->b);
 }
 
 printVolumeEntry(veptr)
@@ -205,20 +219,26 @@ printVolumeEntry(veptr)
 {
     printf("name = %s\n", veptr->name);
     printf("flags = 0x%x", veptr->flags);
-       if (veptr->flags & BUDB_VOL_TAPEERROR) printf(": Tape Error");
-       if (veptr->flags & BUDB_VOL_FILEERROR) printf(": File Error");
-       if (veptr->flags & BUDB_VOL_BEINGWRITTEN) printf(": In progress");
-       if (veptr->flags & BUDB_VOL_FIRSTFRAG)    printf(": First fragment");
-       if (veptr->flags & BUDB_VOL_LASTFRAG)     printf(": Last fragment");
-       if (veptr->flags & BUDB_VOL_ABORTED)      printf(": Aborted");
-       printf("\n");
+    if (veptr->flags & BUDB_VOL_TAPEERROR)
+	printf(": Tape Error");
+    if (veptr->flags & BUDB_VOL_FILEERROR)
+	printf(": File Error");
+    if (veptr->flags & BUDB_VOL_BEINGWRITTEN)
+	printf(": In progress");
+    if (veptr->flags & BUDB_VOL_FIRSTFRAG)
+	printf(": First fragment");
+    if (veptr->flags & BUDB_VOL_LASTFRAG)
+	printf(": Last fragment");
+    if (veptr->flags & BUDB_VOL_ABORTED)
+	printf(": Aborted");
+    printf("\n");
     printf("id = %d\n", veptr->id);
     printf("server = %s\n", veptr->server);
     printf("partition = %d\n", veptr->partition);
     printf("tapeSeq = %d\n", veptr->tapeSeq);
 
     printf("position = %d\n", veptr->position);
-    printf("clone = %s", ctime((time_t *)&veptr->clone));
+    printf("clone = %s", ctime((time_t *) & veptr->clone));
     printf("startByte = %d\n", veptr->startByte);
     printf("nBytes = %d\n", veptr->nBytes);
     printf("seq = %d\n", veptr->seq);
@@ -226,38 +246,38 @@ printVolumeEntry(veptr)
     printf("dump = %d\n", veptr->dump);
     printf("tape = %s\n", veptr->tape);
 }
-  
+
 printVolFragment(fid, vfptr)
      FILE *fid;
      struct volFragment *vfptr;
 {
-    fprintf(fid,"vol = %d\n", vfptr->vol);
-    fprintf(fid,"sameNameChain = %d\n", vfptr->sameNameChain);
-    fprintf(fid,"tape = %d\n", vfptr->tape);
-    fprintf(fid,"sameTapeChain = %d\n", vfptr->sameTapeChain);
-    fprintf(fid,"position = %d\n", vfptr->position);
-    fprintf(fid,"clone = %s", ctime((time_t *)&vfptr->clone));
-    fprintf(fid,"incTime = %s", ctime((time_t *)&vfptr->incTime));
-    fprintf(fid,"startByte = %d\n", vfptr->startByte);
-    fprintf(fid,"nBytes = %d\n", vfptr->nBytes);
-    fprintf(fid,"flags = %d\n", vfptr->flags);
-    fprintf(fid,"sequence = %d\n", vfptr->sequence);
+    fprintf(fid, "vol = %d\n", vfptr->vol);
+    fprintf(fid, "sameNameChain = %d\n", vfptr->sameNameChain);
+    fprintf(fid, "tape = %d\n", vfptr->tape);
+    fprintf(fid, "sameTapeChain = %d\n", vfptr->sameTapeChain);
+    fprintf(fid, "position = %d\n", vfptr->position);
+    fprintf(fid, "clone = %s", ctime((time_t *) & vfptr->clone));
+    fprintf(fid, "incTime = %s", ctime((time_t *) & vfptr->incTime));
+    fprintf(fid, "startByte = %d\n", vfptr->startByte);
+    fprintf(fid, "nBytes = %d\n", vfptr->nBytes);
+    fprintf(fid, "flags = %d\n", vfptr->flags);
+    fprintf(fid, "sequence = %d\n", vfptr->sequence);
 }
 
 printVolInfo(fid, viptr)
      FILE *fid;
      struct volInfo *viptr;
 {
-    fprintf(fid,"name = %s\n", viptr->name);
-    fprintf(fid,"nameHashChain = %d\n", viptr->nameHashChain);
-    fprintf(fid,"id = %d\n", viptr->id);
-    fprintf(fid,"server = %s\n", viptr->server);
-    fprintf(fid,"partition = %d\n", viptr->partition);
-    fprintf(fid,"flags = 0x%x\n", viptr->flags);
-    fprintf(fid,"sameNameHead = %d\n", viptr->sameNameHead);
-    fprintf(fid,"sameNameChain = %d\n", viptr->sameNameChain);
-    fprintf(fid,"firstFragment = %d\n", viptr->firstFragment);
-    fprintf(fid,"nFrags = %d\n", viptr->nFrags);
+    fprintf(fid, "name = %s\n", viptr->name);
+    fprintf(fid, "nameHashChain = %d\n", viptr->nameHashChain);
+    fprintf(fid, "id = %d\n", viptr->id);
+    fprintf(fid, "server = %s\n", viptr->server);
+    fprintf(fid, "partition = %d\n", viptr->partition);
+    fprintf(fid, "flags = 0x%x\n", viptr->flags);
+    fprintf(fid, "sameNameHead = %d\n", viptr->sameNameHead);
+    fprintf(fid, "sameNameChain = %d\n", viptr->sameNameChain);
+    fprintf(fid, "firstFragment = %d\n", viptr->firstFragment);
+    fprintf(fid, "nFrags = %d\n", viptr->nFrags);
 }
 
 
@@ -325,7 +345,7 @@ tape_ntoh(netTapePtr, hostTapePtr)
 dump_ntoh(netDumpPtr, hostDumpPtr)
      struct dump *netDumpPtr, *hostDumpPtr;
 {
-    hostDumpPtr->id = ntohl(netDumpPtr->id);    
+    hostDumpPtr->id = ntohl(netDumpPtr->id);
     hostDumpPtr->idHashChain = ntohl(netDumpPtr->idHashChain);
     strcpy(hostDumpPtr->dumpName, netDumpPtr->dumpName);
     strcpy(hostDumpPtr->dumpPath, netDumpPtr->dumpPath);
@@ -429,8 +449,8 @@ tapeSet_hton(hostptr, netptr)
      struct budb_tapeSet *hostptr, *netptr;
 {
     netptr->id = htonl(hostptr->id);
-    strcpy(netptr->tapeServer, hostptr->tapeServer);    
-    strcpy(netptr->format, hostptr->format);    
+    strcpy(netptr->tapeServer, hostptr->tapeServer);
+    strcpy(netptr->format, hostptr->format);
     netptr->maxTapes = htonl(hostptr->maxTapes);
     netptr->a = htonl(hostptr->a);
     netptr->b = htonl(hostptr->b);
@@ -440,8 +460,8 @@ tapeSet_ntoh(netptr, hostptr)
      struct budb_tapeSet *netptr, *hostptr;
 {
     hostptr->id = ntohl(netptr->id);
-    strcpy(hostptr->tapeServer, netptr->tapeServer);    
-    strcpy(hostptr->format, netptr->format);    
+    strcpy(hostptr->tapeServer, netptr->tapeServer);
+    strcpy(hostptr->format, netptr->format);
     hostptr->maxTapes = ntohl(netptr->maxTapes);
     hostptr->a = ntohl(netptr->a);
     hostptr->b = ntohl(netptr->b);
@@ -468,7 +488,7 @@ textBlock_ntoh(netptr, hostptr)
 }
 
 textLock_hton(hostptr, netptr)
-     db_lockP	hostptr, netptr;
+     db_lockP hostptr, netptr;
 {
     netptr->type = htonl(hostptr->type);
     netptr->lockState = htonl(hostptr->lockState);
@@ -479,7 +499,7 @@ textLock_hton(hostptr, netptr)
 }
 
 textLock_ntoh(netptr, hostptr)
-     db_lockP	netptr, hostptr;
+     db_lockP netptr, hostptr;
 {
     hostptr->type = ntohl(netptr->type);
     hostptr->lockState = ntohl(netptr->lockState);
@@ -499,7 +519,7 @@ volumeEntry_ntoh(netptr, hostptr)
     hostptr->partition = ntohl(netptr->partition);
     hostptr->tapeSeq = ntohl(netptr->tapeSeq);
 
-    hostptr->position  = ntohl(netptr->position);
+    hostptr->position = ntohl(netptr->position);
     hostptr->clone = ntohl(netptr->clone);
     hostptr->incTime = ntohl(netptr->incTime);
     hostptr->startByte = ntohl(netptr->startByte);
@@ -547,9 +567,10 @@ dumpToBudbDump(dumpPtr, budbDumpPtr)
     budbDumpPtr->created = dumpPtr->created;
     budbDumpPtr->nVolumes = dumpPtr->nVolumes;
 
-    bcopy(&dumpPtr->tapes, &budbDumpPtr->tapes, sizeof(struct budb_tapeSet));
-    copy_ktcPrincipal_to_budbPrincipal(&dumpPtr->dumper, &budbDumpPtr->dumper);
-    return(0);
+    memcpy(&budbDumpPtr->tapes, &dumpPtr->tapes, sizeof(struct budb_tapeSet));
+    copy_ktcPrincipal_to_budbPrincipal(&dumpPtr->dumper,
+				       &budbDumpPtr->dumper);
+    return (0);
 }
 
 tapeToBudbTape(tapePtr, budbTapePtr)
@@ -568,7 +589,7 @@ tapeToBudbTape(tapePtr, budbTapePtr)
     budbTapePtr->labelpos = tapePtr->labelpos;
     budbTapePtr->useCount = tapePtr->useCount;
     budbTapePtr->useKBytes = tapePtr->useKBytes;
-    return(0);
+    return (0);
 }
 
 volsToBudbVol(volFragPtr, volInfoPtr, budbVolPtr)
@@ -581,7 +602,7 @@ volsToBudbVol(volFragPtr, volInfoPtr, budbVolPtr)
     budbVolPtr->id = volInfoPtr->id;
     strcpy(budbVolPtr->server, volInfoPtr->server);
     budbVolPtr->partition = volInfoPtr->partition;
-    budbVolPtr->tapeSeq = 0;      /* Don't know it so mark invalid */
+    budbVolPtr->tapeSeq = 0;	/* Don't know it so mark invalid */
 
     budbVolPtr->position = volFragPtr->position;
     budbVolPtr->clone = volFragPtr->clone;
@@ -589,7 +610,7 @@ volsToBudbVol(volFragPtr, volInfoPtr, budbVolPtr)
     budbVolPtr->startByte = volFragPtr->startByte;
     budbVolPtr->nBytes = volFragPtr->nBytes;
     budbVolPtr->seq = volFragPtr->sequence;
-    return(0);
+    return (0);
 }
 
 /* ----------------------------------
@@ -611,7 +632,7 @@ default_tapeset(tapesetPtr, dumpname)
      struct budb_tapeSet *tapesetPtr;
      char *dumpname;
 {
-    bzero(tapesetPtr, sizeof(*tapesetPtr));
+    memset(tapesetPtr, 0, sizeof(*tapesetPtr));
 
     strcpy(tapesetPtr->format, dumpname);
     strcat(tapesetPtr->format, ".%d");
