@@ -14,12 +14,15 @@
 #include "afs/param.h"
 #include <afsconfig.h>
 
-RCSID("$Header: /cvs/openafs/src/rx/xdr_afsuuid.c,v 1.3 2001/07/05 15:20:44 shadow Exp $");
+RCSID
+    ("$Header: /cvs/openafs/src/rx/xdr_afsuuid.c,v 1.7 2003/07/15 23:16:12 shadow Exp $");
 
 #if defined(KERNEL) && !defined(UKERNEL)
 #ifdef AFS_LINUX20_ENV
-#include "../h/string.h"
-#define bzero(A,C) memset((A), 0, (C))
+#include "h/string.h"
+#if 0
+#define bzero(A, C) memset((A), 0, (C))
+#endif
 #else
 #include <sys/param.h>
 #include <sys/systm.h>
@@ -35,27 +38,25 @@ RCSID("$Header: /cvs/openafs/src/rx/xdr_afsuuid.c,v 1.3 2001/07/05 15:20:44 shad
 #endif
 
 int
-xdr_afsUUID(xdrs, objp)
-	XDR *xdrs;
-	afsUUID *objp;
+xdr_afsUUID(XDR * xdrs, afsUUID * objp)
 {
-	if (!xdr_afs_uint32(xdrs, &objp->time_low)) {
-		return (FALSE);
-	}
-	if (!xdr_u_short(xdrs, &objp->time_mid)) {
-		return (FALSE);
-	}
-	if (!xdr_u_short(xdrs, &objp->time_hi_and_version)) {
-		return (FALSE);
-	}
-	if (!xdr_char(xdrs, &objp->clock_seq_hi_and_reserved)) {
-		return (FALSE);
-	}
-	if (!xdr_char(xdrs, &objp->clock_seq_low)) {
-		return (FALSE);
-	}
-	if (!xdr_vector(xdrs, (char *)objp->node, 6, sizeof(char), xdr_char)) {
-		return (FALSE);
-	}
-	return (TRUE);
+    if (!xdr_afs_uint32(xdrs, &objp->time_low)) {
+	return (FALSE);
+    }
+    if (!xdr_u_short(xdrs, &objp->time_mid)) {
+	return (FALSE);
+    }
+    if (!xdr_u_short(xdrs, &objp->time_hi_and_version)) {
+	return (FALSE);
+    }
+    if (!xdr_char(xdrs, &objp->clock_seq_hi_and_reserved)) {
+	return (FALSE);
+    }
+    if (!xdr_char(xdrs, &objp->clock_seq_low)) {
+	return (FALSE);
+    }
+    if (!xdr_vector(xdrs, (char *)objp->node, 6, sizeof(char), xdr_char)) {
+	return (FALSE);
+    }
+    return (TRUE);
 }
