@@ -10,7 +10,8 @@
 #include <afsconfig.h>
 #include <afs/param.h>
 
-RCSID("$Header: /cvs/openafs/src/update/utils.c,v 1.7 2001/08/06 23:50:13 shadow Exp $");
+RCSID
+    ("$Header: /cvs/openafs/src/update/utils.c,v 1.9 2003/07/15 23:17:07 shadow Exp $");
 
 #include <afs/stds.h>
 #include <rx/rxkad.h>
@@ -35,38 +36,44 @@ RCSID("$Header: /cvs/openafs/src/update/utils.c,v 1.7 2001/08/06 23:50:13 shadow
 
 int
 AddToList(ah, aname)
-struct filestr **ah;
-char *aname; {
+     struct filestr **ah;
+     char *aname;
+{
     register struct filestr *tf;
-    tf = (struct filestr *) malloc(sizeof(struct filestr));
+    tf = (struct filestr *)malloc(sizeof(struct filestr));
     tf->next = *ah;
     *ah = tf;
-    tf->name = (char *) malloc(strlen(aname)+1);
+    tf->name = (char *)malloc(strlen(aname) + 1);
     strcpy(tf->name, aname);
     return 0;
 }
 
 int
 ZapList(ah)
-struct filestr **ah; {
+     struct filestr **ah;
+{
     register struct filestr *tf, *nf;
-    for(tf = *ah; tf; tf=nf) {
-	nf = tf->next;	    /* save before freeing */
+    for (tf = *ah; tf; tf = nf) {
+	nf = tf->next;		/* save before freeing */
 	free(tf->name);
 	free(tf);
     }
-    *ah = (struct filestr *) 0;
+    *ah = NULL;
     return 0;
 }
 
 /* StringToLevel - converts the name of an rxkad security level to a integer
  * suitable for calling rxkad_New*SecurityObject. */
 
-rxkad_level StringToLevel (name)
-  char *name;
+rxkad_level
+StringToLevel(name)
+     char *name;
 {
-    if (strcmp (name, "clear") == 0) return rxkad_clear;
-    if (strcmp (name, "auth") == 0) return rxkad_auth;
-    if (strcmp (name, "crypt") == 0) return rxkad_crypt;
+    if (strcmp(name, "clear") == 0)
+	return rxkad_clear;
+    if (strcmp(name, "auth") == 0)
+	return rxkad_auth;
+    if (strcmp(name, "crypt") == 0)
+	return rxkad_crypt;
     return -1;
 }
