@@ -14,7 +14,8 @@
 #include <afsconfig.h>
 #include <afs/param.h>
 
-RCSID("$Header: /cvs/openafs/src/vol/ihandle.c,v 1.7 2002/04/29 23:40:22 shadow Exp $");
+RCSID
+    ("$Header: /cvs/openafs/src/vol/ihandle.c,v 1.16 2003/11/23 04:53:43 jaltman Exp $");
 
 #include <stdio.h>
 #include <sys/types.h>
@@ -30,12 +31,19 @@ RCSID("$Header: /cvs/openafs/src/vol/ihandle.c,v 1.7 2002/04/29 23:40:22 shadow
 #include <sys/resource.h>
 #endif
 #endif
+#ifdef HAVE_STRING_H
+#include <string.h>
+#else
+#ifdef HAVE_STRINGS_H
+#include <strings.h>
+#endif
+#endif
 #include <rx/xdr.h>
 #include <afs/afsint.h>
 #include <errno.h>
 #include <afs/afssyscalls.h>
-#include "ihandle.h"
 #include "nfs.h"
+#include "ihandle.h"
 #include "viceinode.h"
 #ifdef AFS_PTHREAD_ENV
 #include <assert.h>
@@ -44,6 +52,16 @@ RCSID("$Header: /cvs/openafs/src/vol/ihandle.c,v 1.7 2002/04/29 23:40:22 shadow
 #endif /* AFS_PTHREAD_ENV */
 #include <limits.h>
 
+#ifndef AFS_NT40_ENV
+#ifdef O_LARGEFILE
+#define afs_stat	stat64
+#define afs_fstat	fstat64
+#else /* !O_LARGEFILE */
+#define	afs_stat	stat
+#define	afs_fstat	fstat
+#endif /* !O_LARGEFILE */
+#endif /* AFS_NT40_ENV */
+
 extern afs_int32 DErrno;
 
 #ifdef AFS_PTHREAD_ENV
@@ -85,21 +103,24 @@ IHashBucket_t ihashTable[I_HANDLE_HASH_SIZE];
 
 #ifdef AFS_PTHREAD_ENV
 /* Initialize the global ihandle mutex */
-void ih_glock_init()
+void
+ih_glock_init()
 {
     assert(pthread_mutex_init(&ih_glock_mutex, NULL) == 0);
 }
 #endif /* AFS_PTHREAD_ENV */
 
 /* Initialize the file descriptor cache */
-void ih_Initialize() {
+void
+ih_Initialize(void)
+{
     int i;
     assert(!ih_Inited);
     ih_Inited = 1;
     DLL_INIT_LIST(ihAvailHead, ihAvailTail);
     DLL_INIT_LIST(fdAvailHead, fdAvailTail);
     DLL_INIT_LIST(fdLruHead, fdLruTail);
-    for (i = 0 ; i < I_HANDLE_HASH_SIZE ; i++) {
+    for (i = 0; i < I_HANDLE_HASH_SIZE; i++) {
 	DLL_INIT_LIST(ihashTable[i].ihash_head, ihashTable[i].ihash_tail);
     }
 #if defined(AFS_NT40_ENV)
@@ -110,7 +131,7 @@ void ih_Initialize() {
 	assert(getrlimit(RLIMIT_NOFILE, &rlim) == 0);
 	rlim.rlim_cur = rlim.rlim_max;
 	assert(setrlimit(RLIMIT_NOFILE, &rlim) == 0);
-	fdMaxCacheSize = rlim.rlim_cur-FD_HANDLE_SETASIDE;
+	fdMaxCacheSize = rlim.rlim_cur - FD_HANDLE_SETASIDE;
 #ifdef AFS_NBSD_ENV
 	/* XXX this is to avoid using up all system fd netbsd is
 	 * somewhat broken and have set maximum fd for a root process
@@ -129,58 +150,58 @@ void ih_Initialize() {
     /* Avoid problems with "UFSOpen: igetinode failed" panics on HPUX 11.0 */
     fdMaxCacheSize = 0;
 #else
-    fdMaxCacheSize = MAX(sysconf(_SC_OPEN_MAX)-FD_HANDLE_SETASIDE, 0);
-    fdMaxCacheSize = MIN(fdMaxCacheSize, FD_MAX_CACHESIZE);
+    {
+	long fdMax = MAX(sysconf(_SC_OPEN_MAX) - FD_HANDLE_SETASIDE, 0);
+	fdMaxCacheSize = (int)MIN(fdMax, FD_MAX_CACHESIZE);
+    }
 #endif
     fdCacheSize = MIN(fdMaxCacheSize, FD_DEFAULT_CACHESIZE);
 }
 
 /* Make the file descriptor cache as big as possible. Don't this call
  * if the program uses fopen or fdopen. */
-void ih_UseLargeCache() {
-    IH_LOCK
-
-    if (!ih_Inited) {
+void
+ih_UseLargeCache(void)
+{
+    IH_LOCK if (!ih_Inited) {
 	ih_Initialize();
     }
     fdCacheSize = fdMaxCacheSize;
 
-    IH_UNLOCK
-}
+IH_UNLOCK}
 
 /* Allocate a chunk of inode handles */
-void iHandleAllocateChunk()
+void
+iHandleAllocateChunk(void)
 {
     int i;
     IHandle_t *ihP;
 
     assert(ihAvailHead == NULL);
-    ihP = (IHandle_t *)malloc(I_HANDLE_MALLOCSIZE * sizeof(IHandle_t));
+    ihP = (IHandle_t *) malloc(I_HANDLE_MALLOCSIZE * sizeof(IHandle_t));
     assert(ihP != NULL);
-    for (i = 0 ; i < I_HANDLE_MALLOCSIZE ; i++) {
+    for (i = 0; i < I_HANDLE_MALLOCSIZE; i++) {
 	ihP[i].ih_refcnt = 0;
 	DLL_INSERT_TAIL(&ihP[i], ihAvailHead, ihAvailTail, ih_next, ih_prev);
     }
 }
 
 /* Initialize an inode handle */
-IHandle_t *ih_init(int dev, int vid, Inode ino)
+IHandle_t *
+ih_init(int dev, int vid, Inode ino)
 {
     int ihash = IH_HASH(dev, vid, ino);
     IHandle_t *ihP;
 
-    IH_LOCK
-
-    if (!ih_Inited) {
+    IH_LOCK if (!ih_Inited) {
 	ih_Initialize();
     }
 
     /* Do we already have a handle for this Inode? */
-    for (ihP = ihashTable[ihash].ihash_head ; ihP ; ihP = ihP->ih_next) {
+    for (ihP = ihashTable[ihash].ihash_head; ihP; ihP = ihP->ih_next) {
 	if (ihP->ih_ino == ino && ihP->ih_vid == vid && ihP->ih_dev == dev) {
 	    ihP->ih_refcnt++;
-	    IH_UNLOCK
-	    return ihP;
+	    IH_UNLOCK return ihP;
 	}
     }
 
@@ -199,31 +220,30 @@ IHandle_t *ih_init(int dev, int vid, Inode ino)
     DLL_INIT_LIST(ihP->ih_fdhead, ihP->ih_fdtail);
     DLL_INSERT_TAIL(ihP, ihashTable[ihash].ihash_head,
 		    ihashTable[ihash].ihash_tail, ih_next, ih_prev);
-    IH_UNLOCK
-    return ihP;
+    IH_UNLOCK return ihP;
 }
 
 /* Copy an inode handle */
-IHandle_t *ih_copy(IHandle_t *ihP)
+IHandle_t *
+ih_copy(IHandle_t * ihP)
 {
-    IH_LOCK
-    assert(ih_Inited);
+    IH_LOCK assert(ih_Inited);
     assert(ihP->ih_refcnt > 0);
     ihP->ih_refcnt++;
-    IH_UNLOCK
-    return ihP;
+    IH_UNLOCK return ihP;
 }
 
 /* Allocate a chunk of file descriptor handles */
-void fdHandleAllocateChunk()
+void
+fdHandleAllocateChunk(void)
 {
     int i;
     FdHandle_t *fdP;
 
     assert(fdAvailHead == NULL);
-    fdP = (FdHandle_t *)malloc(FD_HANDLE_MALLOCSIZE * sizeof(FdHandle_t));
+    fdP = (FdHandle_t *) malloc(FD_HANDLE_MALLOCSIZE * sizeof(FdHandle_t));
     assert(fdP != NULL);
-    for (i = 0 ; i < FD_HANDLE_MALLOCSIZE ; i++) {
+    for (i = 0; i < FD_HANDLE_MALLOCSIZE; i++) {
 	fdP[i].fd_status = FD_HANDLE_AVAIL;
 	fdP[i].fd_ih = NULL;
 	fdP[i].fd_fd = INVALID_FD;
@@ -232,16 +252,17 @@ void fdHandleAllocateChunk()
 }
 
 /* Allocate a chunk of stream handles */
-void streamHandleAllocateChunk()
+void
+streamHandleAllocateChunk(void)
 {
     int i;
     StreamHandle_t *streamP;
 
     assert(streamAvailHead == NULL);
     streamP = (StreamHandle_t *)
-	      malloc(STREAM_HANDLE_MALLOCSIZE * sizeof(StreamHandle_t));
+	malloc(STREAM_HANDLE_MALLOCSIZE * sizeof(StreamHandle_t));
     assert(streamP != NULL);
-    for (i = 0 ; i < STREAM_HANDLE_MALLOCSIZE ; i++) {
+    for (i = 0; i < STREAM_HANDLE_MALLOCSIZE; i++) {
 	streamP[i].str_fd = INVALID_FD;
 	DLL_INSERT_TAIL(&streamP[i], streamAvailHead, streamAvailTail,
 			str_next, str_prev);
@@ -251,23 +272,25 @@ void streamHandleAllocateChunk()
 /*
  * Get a file descriptor handle given an Inode handle
  */
-FdHandle_t *ih_open(IHandle_t *ihP)
+FdHandle_t *
+ih_open(IHandle_t * ihP)
 {
     FdHandle_t *fdP;
     FD_t fd;
     FD_t closeFd;
 
-    IH_LOCK
+    if (!ihP)			/* XXX should log here in the fileserver */
+	return NULL;
 
-    /* Do we already have an open file handle for this Inode? */
-    for (fdP = ihP->ih_fdtail ; fdP != NULL ; fdP = fdP->fd_ihprev) {
+    IH_LOCK
+	/* Do we already have an open file handle for this Inode? */
+	for (fdP = ihP->ih_fdtail; fdP != NULL; fdP = fdP->fd_ihprev) {
 	if (fdP->fd_status != FD_HANDLE_INUSE) {
 	    assert(fdP->fd_status == FD_HANDLE_OPEN);
 	    fdP->fd_status = FD_HANDLE_INUSE;
 	    DLL_DELETE(fdP, fdLruHead, fdLruTail, fd_next, fd_prev);
 	    ihP->ih_refcnt++;
-	    IH_UNLOCK
-	    FDH_SEEK(fdP, 0, SEEK_SET);
+	    IH_UNLOCK(void) FDH_SEEK(fdP, 0, SEEK_SET);
 	    return fdP;
 	}
     }
@@ -276,13 +299,10 @@ FdHandle_t *ih_open(IHandle_t *ihP)
      * Try to open the Inode, return NULL on error.
      */
     fdInUseCount += 1;
-    IH_UNLOCK
-    fd = OS_IOPEN(ihP);
-    IH_LOCK
-    if (fd == INVALID_FD) {
+    IH_UNLOCK fd = OS_IOPEN(ihP);
+    IH_LOCK if (fd == INVALID_FD) {
 	fdInUseCount -= 1;
-	IH_UNLOCK
-	return NULL;
+	IH_UNLOCK return NULL;
     }
 
     /* fdCacheSize limits the size of the descriptor cache, but
@@ -294,7 +314,7 @@ FdHandle_t *ih_open(IHandle_t *ihP)
 	assert(fdP->fd_status == FD_HANDLE_OPEN);
 	DLL_DELETE(fdP, fdLruHead, fdLruTail, fd_next, fd_prev);
 	DLL_DELETE(fdP, fdP->fd_ih->ih_fdhead, fdP->fd_ih->ih_fdtail,
-            fd_ihnext, fd_ihprev);
+		   fd_ihnext, fd_ihprev);
 	closeFd = fdP->fd_fd;
     } else {
 	if (fdAvailHead == NULL) {
@@ -313,33 +333,29 @@ FdHandle_t *ih_open(IHandle_t *ihP)
     ihP->ih_refcnt++;
 
     /* Add this handle to the Inode's list of open descriptors */
-    DLL_INSERT_TAIL(fdP, ihP->ih_fdhead, ihP->ih_fdtail, fd_ihnext, fd_ihprev);
+    DLL_INSERT_TAIL(fdP, ihP->ih_fdhead, ihP->ih_fdtail, fd_ihnext,
+		    fd_ihprev);
 
     if (closeFd != INVALID_FD) {
-	IH_UNLOCK
-	OS_CLOSE(closeFd);
-	IH_LOCK
-	fdInUseCount -= 1;
+	IH_UNLOCK OS_CLOSE(closeFd);
+	IH_LOCK fdInUseCount -= 1;
     }
 
-    IH_UNLOCK
-    return fdP;
+    IH_UNLOCK return fdP;
 }
 
 /*
  * Return a file descriptor handle to the cache
  */
-int fd_close(FdHandle_t *fdP)
+int
+fd_close(FdHandle_t * fdP)
 {
-    FD_t closeFd;
     IHandle_t *ihP;
 
     if (!fdP)
 	return 0;
 
-    IH_LOCK
-
-    assert(ih_Inited);
+    IH_LOCK assert(ih_Inited);
     assert(fdInUseCount > 0);
     assert(fdP->fd_status == FD_HANDLE_INUSE);
 
@@ -351,8 +367,7 @@ int fd_close(FdHandle_t *fdP)
      * IH_REALLY_CLOSED) or we have too many open files.
      */
     if (ihP->ih_flags & IH_REALLY_CLOSED || fdInUseCount > fdCacheSize) {
-	IH_UNLOCK
-	return fd_reallyclose(fdP);
+	IH_UNLOCK return fd_reallyclose(fdP);
     }
 
     /* Put this descriptor back into the cache */
@@ -364,10 +379,8 @@ int fd_close(FdHandle_t *fdP)
      */
     if (ihP->ih_refcnt > 1) {
 	ihP->ih_refcnt--;
-	IH_UNLOCK
-    } else {
-	IH_UNLOCK
-	ih_release(ihP);
+    IH_UNLOCK} else {
+	IH_UNLOCK ih_release(ihP);
     }
 
     return 0;
@@ -377,7 +390,8 @@ int fd_close(FdHandle_t *fdP)
  * Actually close the file descriptor handle and return it to
  * the free list.
  */
-int fd_reallyclose(FdHandle_t *fdP)
+int
+fd_reallyclose(FdHandle_t * fdP)
 {
     FD_t closeFd;
     IHandle_t *ihP;
@@ -385,9 +399,7 @@ int fd_reallyclose(FdHandle_t *fdP)
     if (!fdP)
 	return 0;
 
-    IH_LOCK
-
-    assert(ih_Inited);
+    IH_LOCK assert(ih_Inited);
     assert(fdInUseCount > 0);
     assert(fdP->fd_status == FD_HANDLE_INUSE);
 
@@ -406,42 +418,35 @@ int fd_reallyclose(FdHandle_t *fdP)
      * has completed its job.
      */
     if (!ihP->ih_fdhead) {
-        ihP->ih_flags &= ~IH_REALLY_CLOSED;
+	ihP->ih_flags &= ~IH_REALLY_CLOSED;
     }
 
-    IH_UNLOCK
-    OS_CLOSE(closeFd);
-    IH_LOCK
-
-    fdInUseCount -= 1;
+    IH_UNLOCK OS_CLOSE(closeFd);
+    IH_LOCK fdInUseCount -= 1;
 
     /* If this is not the only reference to the Inode then we can decrement
      * the reference count, otherwise we need to call ih_release. */
     if (ihP->ih_refcnt > 1) {
 	ihP->ih_refcnt--;
-	IH_UNLOCK
-    } else {
-	IH_UNLOCK
-	ih_release(ihP);
+    IH_UNLOCK} else {
+	IH_UNLOCK ih_release(ihP);
     }
 
     return 0;
 }
 
 /* Enable buffered I/O on a file descriptor */
-StreamHandle_t *stream_fdopen(FD_t fd)
+StreamHandle_t *
+stream_fdopen(FD_t fd)
 {
     StreamHandle_t *streamP;
 
-    IH_LOCK
-    if (streamAvailHead == NULL) {
+    IH_LOCK if (streamAvailHead == NULL) {
 	streamHandleAllocateChunk();
     }
     streamP = streamAvailHead;
     DLL_DELETE(streamP, streamAvailHead, streamAvailTail, str_next, str_prev);
-    IH_UNLOCK
-
-    streamP->str_fd = fd;
+    IH_UNLOCK streamP->str_fd = fd;
     streamP->str_buflen = 0;
     streamP->str_bufoff = 0;
     streamP->str_error = 0;
@@ -451,7 +456,8 @@ StreamHandle_t *stream_fdopen(FD_t fd)
 }
 
 /* Open a file for buffered I/O */
-StreamHandle_t *stream_open(const char *filename, const char *mode)
+StreamHandle_t *
+stream_open(const char *filename, const char *mode)
 {
     FD_t fd;
 
@@ -460,15 +466,15 @@ StreamHandle_t *stream_open(const char *filename, const char *mode)
     } else if (strcmp(mode, "r+") == 0) {
 	fd = OS_OPEN(filename, O_RDWR, 0);
     } else if (strcmp(mode, "w") == 0) {
-	fd = OS_OPEN(filename, O_WRONLY|O_TRUNC|O_CREAT, 0);
+	fd = OS_OPEN(filename, O_WRONLY | O_TRUNC | O_CREAT, 0);
     } else if (strcmp(mode, "w+") == 0) {
-	fd = OS_OPEN(filename, O_RDWR|O_TRUNC|O_CREAT, 0);
+	fd = OS_OPEN(filename, O_RDWR | O_TRUNC | O_CREAT, 0);
     } else if (strcmp(mode, "a") == 0) {
-	fd = OS_OPEN(filename, O_WRONLY|O_APPEND|O_CREAT, 0);
+	fd = OS_OPEN(filename, O_WRONLY | O_APPEND | O_CREAT, 0);
     } else if (strcmp(mode, "a+") == 0) {
-	fd = OS_OPEN(filename, O_RDWR|O_APPEND|O_CREAT, 0);
+	fd = OS_OPEN(filename, O_RDWR | O_APPEND | O_CREAT, 0);
     } else {
-	assert(FALSE); /* not implemented */
+	assert(FALSE);		/* not implemented */
     }
 
     if (fd == INVALID_FD) {
@@ -478,9 +484,11 @@ StreamHandle_t *stream_open(const char *filename, const char *mode)
 }
 
 /* fread for buffered I/O handles */
-int stream_read(void *ptr, int size, int nitems, StreamHandle_t *streamP)
+afs_sfsize_t
+stream_read(void *ptr, afs_fsize_t size, afs_fsize_t nitems,
+	    StreamHandle_t * streamP)
 {
-    int nbytes, bytesRead, bytesToRead;
+    afs_fsize_t nbytes, bytesRead, bytesToRead;
     char *p;
 
     /* Need to seek before changing direction */
@@ -498,8 +506,9 @@ int stream_read(void *ptr, int size, int nitems, StreamHandle_t *streamP)
     while (nbytes > 0 && !streamP->str_eof) {
 	if (streamP->str_buflen == 0) {
 	    streamP->str_bufoff = 0;
-	    streamP->str_buflen = OS_READ(streamP->str_fd, streamP->str_buffer,
-				          STREAM_HANDLE_BUFSIZE);
+	    streamP->str_buflen =
+		OS_READ(streamP->str_fd, streamP->str_buffer,
+			STREAM_HANDLE_BUFSIZE);
 	    if (streamP->str_buflen < 0) {
 		streamP->str_error = errno;
 		streamP->str_buflen = 0;
@@ -515,7 +524,7 @@ int stream_read(void *ptr, int size, int nitems, StreamHandle_t *streamP)
 	if (bytesToRead > streamP->str_buflen) {
 	    bytesToRead = streamP->str_buflen;
 	}
-	memcpy(p, streamP->str_buffer+streamP->str_bufoff, bytesToRead);
+	memcpy(p, streamP->str_buffer + streamP->str_bufoff, bytesToRead);
 	p += bytesToRead;
 	streamP->str_bufoff += bytesToRead;
 	streamP->str_buflen -= bytesToRead;
@@ -523,14 +532,17 @@ int stream_read(void *ptr, int size, int nitems, StreamHandle_t *streamP)
 	nbytes -= bytesToRead;
     }
 
-    return (bytesRead/size);
+    return (bytesRead / size);
 }
 
 /* fwrite for buffered I/O handles */
-int stream_write(void *ptr, int size, int nitems, StreamHandle_t *streamP)
+afs_sfsize_t
+stream_write(void *ptr, afs_fsize_t size, afs_fsize_t nitems,
+	     StreamHandle_t * streamP)
 {
     char *p;
-    int rc, nbytes, bytesWritten, bytesToWrite;
+    afs_sfsize_t rc;
+    afs_fsize_t nbytes, bytesWritten, bytesToWrite;
 
     /* Need to seek before changing direction */
     if (streamP->str_direction == STREAM_DIRECTION_NONE) {
@@ -561,7 +573,7 @@ int stream_write(void *ptr, int size, int nitems, StreamHandle_t *streamP)
 	if (bytesToWrite > streamP->str_buflen) {
 	    bytesToWrite = streamP->str_buflen;
 	}
-	memcpy(streamP->str_buffer+streamP->str_bufoff, p, bytesToWrite);
+	memcpy(streamP->str_buffer + streamP->str_bufoff, p, bytesToWrite);
 	p += bytesToWrite;
 	streamP->str_bufoff += bytesToWrite;
 	streamP->str_buflen -= bytesToWrite;
@@ -569,17 +581,18 @@ int stream_write(void *ptr, int size, int nitems, StreamHandle_t *streamP)
 	nbytes -= bytesToWrite;
     }
 
-    return (bytesWritten/size);
+    return (bytesWritten / size);
 }
 
 /* fseek for buffered I/O handles */
-int stream_seek(StreamHandle_t *streamP, int offset, int whence)
+int
+stream_seek(StreamHandle_t * streamP, afs_foff_t offset, int whence)
 {
     int rc;
     int retval = 0;
 
-    if (streamP->str_direction == STREAM_DIRECTION_WRITE &&
-	streamP->str_bufoff > 0) {
+    if (streamP->str_direction == STREAM_DIRECTION_WRITE
+	&& streamP->str_bufoff > 0) {
 	rc = OS_WRITE(streamP->str_fd, streamP->str_buffer,
 		      streamP->str_bufoff);
 	if (rc < 0) {
@@ -599,13 +612,14 @@ int stream_seek(StreamHandle_t *streamP, int offset, int whence)
 }
 
 /* fflush for buffered I/O handles */
-int stream_flush(StreamHandle_t *streamP)
+int
+stream_flush(StreamHandle_t * streamP)
 {
     int rc;
     int retval = 0;
 
-    if (streamP->str_direction == STREAM_DIRECTION_WRITE &&
-	streamP->str_bufoff > 0) {
+    if (streamP->str_direction == STREAM_DIRECTION_WRITE
+	&& streamP->str_bufoff > 0) {
 	rc = OS_WRITE(streamP->str_fd, streamP->str_buffer,
 		      streamP->str_bufoff);
 	if (rc < 0) {
@@ -620,14 +634,15 @@ int stream_flush(StreamHandle_t *streamP)
 }
 
 /* Free a buffered I/O handle */
-int stream_close(StreamHandle_t *streamP, int reallyClose)
+int
+stream_close(StreamHandle_t * streamP, int reallyClose)
 {
     int rc;
     int retval = 0;
 
     assert(streamP != NULL);
-    if (streamP->str_direction == STREAM_DIRECTION_WRITE &&
-	streamP->str_bufoff > 0) {
+    if (streamP->str_direction == STREAM_DIRECTION_WRITE
+	&& streamP->str_bufoff > 0) {
 	rc = OS_WRITE(streamP->str_fd, streamP->str_buffer,
 		      streamP->str_bufoff);
 	if (rc < 0) {
@@ -642,12 +657,9 @@ int stream_close(StreamHandle_t *streamP, int reallyClose)
     }
     streamP->str_fd = INVALID_FD;
 
-    IH_LOCK
-    DLL_INSERT_TAIL(streamP, streamAvailHead, streamAvailTail,
-		    str_next, str_prev);
-    IH_UNLOCK
-
-    return retval;
+    IH_LOCK DLL_INSERT_TAIL(streamP, streamAvailHead, streamAvailTail,
+			    str_next, str_prev);
+    IH_UNLOCK return retval;
 }
 
 /* Close all unused file descriptors associated with the inode
@@ -655,7 +667,8 @@ int stream_close(StreamHandle_t *streamP, int reallyClose)
  * IH_LOCK. Sets the IH_REALLY_CLOSED flag in the inode handle
  * if it fails to close all file handles.
  */
-static int ih_fdclose(IHandle_t *ihP)
+static int
+ih_fdclose(IHandle_t * ihP)
 {
     int closeCount, closedAll;
     FdHandle_t *fdP, *head, *tail, *next;
@@ -672,107 +685,99 @@ static int ih_fdclose(IHandle_t *ihP)
      * can drop the lock before we close the files.
      */
     for (fdP = ihP->ih_fdhead; fdP != NULL; fdP = next) {
-        next = fdP->fd_ihnext;
-        assert(fdP->fd_ih == ihP);
-        assert(fdP->fd_status == FD_HANDLE_OPEN ||
-               fdP->fd_status == FD_HANDLE_INUSE);
-        if (fdP->fd_status == FD_HANDLE_OPEN) {
-            DLL_DELETE(fdP, ihP->ih_fdhead, ihP->ih_fdtail,
-                fd_ihnext, fd_ihprev);
-            DLL_DELETE(fdP, fdLruHead, fdLruTail, fd_next, fd_prev);
-            DLL_INSERT_TAIL(fdP, head, tail, fd_next, fd_prev);
-        } else {
-            closedAll = 0;
-            ihP->ih_flags |= IH_REALLY_CLOSED;
-        }
+	next = fdP->fd_ihnext;
+	assert(fdP->fd_ih == ihP);
+	assert(fdP->fd_status == FD_HANDLE_OPEN
+	       || fdP->fd_status == FD_HANDLE_INUSE);
+	if (fdP->fd_status == FD_HANDLE_OPEN) {
+	    DLL_DELETE(fdP, ihP->ih_fdhead, ihP->ih_fdtail, fd_ihnext,
+		       fd_ihprev);
+	    DLL_DELETE(fdP, fdLruHead, fdLruTail, fd_next, fd_prev);
+	    DLL_INSERT_TAIL(fdP, head, tail, fd_next, fd_prev);
+	} else {
+	    closedAll = 0;
+	    ihP->ih_flags |= IH_REALLY_CLOSED;
+	}
     }
 
     /* If the ihandle reference count is 1, we should have
      * closed all file descriptors.
      */
     if (ihP->ih_refcnt == 1 || closedAll) {
-        assert(closedAll);
-        assert(!ihP->ih_fdhead);
-        assert(!ihP->ih_fdtail);
+	assert(closedAll);
+	assert(!ihP->ih_fdhead);
+	assert(!ihP->ih_fdtail);
     }
 
     if (head == NULL) {
-        return 0;       /* No file descriptors closed */
+	return 0;		/* No file descriptors closed */
     }
 
     IH_UNLOCK
-
-    /*
-     * Close the file descriptors
-     */
-    closeCount = 0;
+	/*
+	 * Close the file descriptors
+	 */
+	closeCount = 0;
     for (fdP = head; fdP != NULL; fdP = fdP->fd_next) {
-        OS_CLOSE(fdP->fd_fd);
-        fdP->fd_status = FD_HANDLE_AVAIL;
-        fdP->fd_fd = INVALID_FD;
-        fdP->fd_ih = NULL;
-        closeCount++;
+	OS_CLOSE(fdP->fd_fd);
+	fdP->fd_status = FD_HANDLE_AVAIL;
+	fdP->fd_fd = INVALID_FD;
+	fdP->fd_ih = NULL;
+	closeCount++;
     }
 
-    IH_LOCK
-
-    assert(fdInUseCount >= closeCount);
+    IH_LOCK assert(fdInUseCount >= closeCount);
     fdInUseCount -= closeCount;
 
     /*
      * Append the temporary queue to the list of available descriptors
      */
     if (fdAvailHead == NULL) {
-        fdAvailHead = head;
-        fdAvailTail = tail;
+	fdAvailHead = head;
+	fdAvailTail = tail;
     } else {
-        fdAvailTail->fd_next = head;
-        head->fd_prev = fdAvailTail;
-        fdAvailTail = tail;
+	fdAvailTail->fd_next = head;
+	head->fd_prev = fdAvailTail;
+	fdAvailTail = tail;
     }
 
     return 0;
 }
 
 /* Close all cached file descriptors for this inode. */
-int ih_reallyclose(IHandle_t *ihP)
+int
+ih_reallyclose(IHandle_t * ihP)
 {
     if (!ihP)
-        return 0;
+	return 0;
 
-    IH_LOCK
-
-    assert(ihP->ih_refcnt > 0);
+    IH_LOCK assert(ihP->ih_refcnt > 0);
     ih_fdclose(ihP);
 
-    IH_UNLOCK
-
-    return 0;
+    IH_UNLOCK return 0;
 }
 
 /* Release an Inode handle. All cached file descriptors for this
  * inode are closed when the last reference to this handle is released
  */
-int ih_release(IHandle_t *ihP)
+int
+ih_release(IHandle_t * ihP)
 {
     int ihash;
 
     if (!ihP)
-        return 0;
+	return 0;
 
-    IH_LOCK
-
-    assert(ihP->ih_refcnt > 0);
+    IH_LOCK assert(ihP->ih_refcnt > 0);
 
     if (ihP->ih_refcnt > 1) {
-        ihP->ih_refcnt--;
-        IH_UNLOCK
-        return 0;
+	ihP->ih_refcnt--;
+	IH_UNLOCK return 0;
     }
 
     ihash = IH_HASH(ihP->ih_dev, ihP->ih_vid, ihP->ih_ino);
     DLL_DELETE(ihP, ihashTable[ihash].ihash_head,
-        ihashTable[ihash].ihash_tail, ih_next, ih_prev);
+	       ihashTable[ihash].ihash_tail, ih_next, ih_prev);
 
     ih_fdclose(ihP);
 
@@ -780,13 +785,12 @@ int ih_release(IHandle_t *ihP)
 
     DLL_INSERT_TAIL(ihP, ihAvailHead, ihAvailTail, ih_next, ih_prev);
 
-    IH_UNLOCK
-
-    return 0;
+    IH_UNLOCK return 0;
 }
 
 /* Sync an inode to disk if its handle isn't NULL */
-int ih_condsync(IHandle_t *ihP)
+int
+ih_condsync(IHandle_t * ihP)
 {
     int code;
     FdHandle_t *fdP;
@@ -810,8 +814,9 @@ int ih_condsync(IHandle_t *ihP)
  * OS specific support routines.
  *************************************************************************/
 #ifndef AFS_NAMEI_ENV
-Inode ih_icreate(IHandle_t *ih, int dev, char *part, Inode nI, int p1, int p2,
-	      int p3, int p4)
+Inode
+ih_icreate(IHandle_t * ih, int dev, char *part, Inode nI, int p1, int p2,
+	   int p3, int p4)
 {
     Inode ino;
 #ifdef	AFS_3DISPARES
@@ -829,10 +834,11 @@ Inode ih_icreate(IHandle_t *ih, int dev, char *part, Inode nI, int p1, int p2,
 
 
 #ifndef AFS_NT40_ENV
-int ih_size(int fd)
+afs_sfsize_t
+ih_size(int fd)
 {
-    struct stat status;
-    if (fstat(fd, &status)<0)
+    struct afs_stat status;
+    if (afs_fstat(fd, &status) < 0)
 	return -1;
     return status.st_size;
 }
